@@ -1,36 +1,46 @@
 import { css } from '@emotion/css';
 import { useFormContext } from 'react-hook-form';
 
+import { GrafanaTheme2 } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
 import { Button, Stack, useStyles2 } from '@grafana/ui';
 import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
+import { SavedQuery } from 'app/features/explore/QueryLibrary/types';
+import { DrilldownExtensionPoint } from 'app/features/explore/extensions/DrilldownExtensionPoint';
 
 import { showDiscardAddQueryModal } from '..';
 import { QueryLibraryInteractions } from '../QueryLibraryAnalyticsEvents';
 import { selectors } from '../e2e-selectors/selectors';
-import { QueryTemplateRow } from '../types';
 import { canEditQuery } from '../utils/identity';
 import { hasUnresolvedVariables } from '../utils/templateVariables';
 
 import { QueryDetails } from './QueryLibraryDetails';
+import { QueryLibraryMenuActions } from './QueryLibraryMenuActions';
 
 export interface QueryLibraryActionsProps {
-  selectedQueryRow: QueryTemplateRow;
-  isEditingQuery: boolean;
-  setIsEditingQuery: (isEditingQuery: boolean) => void;
+  selectedQueryRow: SavedQuery;
   isSavingLoading: boolean;
   usingHistory?: boolean;
+  onEditQuerySuccess: (uid: string, isNew?: boolean) => void;
 }
 
 export function QueryLibraryActions({
   selectedQueryRow,
-  isEditingQuery,
-  setIsEditingQuery,
   usingHistory,
   isSavingLoading,
+  onEditQuerySuccess,
 }: QueryLibraryActionsProps) {
   const styles = useStyles2(getStyles);
-  const { setNewQuery, context, triggerAnalyticsEvent, closeDrawer, onSelectQuery } = useQueryLibraryContext();
+  const {
+    setNewQuery,
+    context,
+    triggerAnalyticsEvent,
+    closeDrawer,
+    onSelectQuery,
+    onAddHistoryQueryToLibrary,
+    isEditingQuery,
+    setIsEditingQuery,
+  } = useQueryLibraryContext();
 
   const hasTemplateVariables = hasUnresolvedVariables(selectedQueryRow.query);
 
@@ -39,20 +49,19 @@ export function QueryLibraryActions({
     formState: { isDirty },
   } = useFormContext<QueryDetails>();
 
-  const onAddHistoryQueryToLibrary = () => {
-    setNewQuery({
-      ...selectedQueryRow,
-      uid: undefined,
-      title: t('explore.query-library.default-title', 'New query'),
-    });
-    setIsEditingQuery(true);
-    triggerAnalyticsEvent(QueryLibraryInteractions.saveRecentQueryClicked);
-  };
-
   if (usingHistory) {
     return (
       <Stack width="100%" justifyContent="flex-end">
-        <Button data-testid={selectors.components.queryLibraryDrawer.confirm} onClick={onAddHistoryQueryToLibrary}>
+        <Button
+          data-testid={selectors.components.queryLibraryDrawer.confirm}
+          onClick={() =>
+            onAddHistoryQueryToLibrary({
+              ...selectedQueryRow,
+              uid: undefined,
+              title: t('explore.query-library.default-title', 'New query'),
+            })
+          }
+        >
           <Trans i18nKey="query-library.actions.save-history-query-button">Save query</Trans>
         </Button>
       </Stack>
@@ -71,7 +80,7 @@ export function QueryLibraryActions({
   };
 
   const onCancelEditClick = () => {
-    if (isDirty) {
+    if (isDirty && context !== 'unknown') {
       showDiscardAddQueryModal(resetForm);
     } else {
       resetForm();
@@ -111,25 +120,34 @@ export function QueryLibraryActions({
           </Stack>
         </div>
       ) : (
-        <Button
-          data-testid={selectors.components.queryLibraryDrawer.confirm}
-          disabled={hasTemplateVariables && context === 'explore'}
-          onClick={() => {
-            onSelectQuery(selectedQueryRow.query);
-            //close drawer
-            closeDrawer();
-            // trigger analytics event
-            triggerAnalyticsEvent(QueryLibraryInteractions.selectQueryClicked);
-          }}
-        >
-          <Trans i18nKey="query-library.actions.select-query-button">Select query</Trans>
-        </Button>
+        <>
+          <QueryLibraryMenuActions selectedQueryRow={selectedQueryRow} onEditQuerySuccess={onEditQuerySuccess} />
+          {!isEditingQuery && selectedQueryRow.uid && context !== 'drilldown' && (
+            <DrilldownExtensionPoint
+              queries={[selectedQueryRow.query]}
+              onExtensionClick={() => {
+                triggerAnalyticsEvent(QueryLibraryInteractions.openInDrilldownClicked);
+              }}
+            />
+          )}
+          <Button
+            data-testid={selectors.components.queryLibraryDrawer.confirm}
+            disabled={hasTemplateVariables && context === 'explore'}
+            onClick={() => {
+              onSelectQuery(selectedQueryRow.query);
+              closeDrawer(true);
+              triggerAnalyticsEvent(QueryLibraryInteractions.selectQueryClicked, { hasTemplateVariables });
+            }}
+          >
+            <Trans i18nKey="query-library.actions.select-query-button">Select query</Trans>
+          </Button>
+        </>
       )}
     </Stack>
   );
 }
 
-const getStyles = () => {
+const getStyles = (theme: GrafanaTheme2) => {
   return {
     editActionsContainer: css({
       marginLeft: 'auto',
